@@ -42,36 +42,40 @@ def eval_str(holding_scope, name):
 def eval_str2(holding_scope, name):
     try:
         # parenthesizing for handling cases like 'a_var.\nattr'
-        node = ast.parse('(%s)' % name)
+        node = ast.parse("(%s)" % name)
     except SyntaxError:
-        raise BadIdentifierError(
-            'Not a resolvable python identifier selected.')
+        raise BadIdentifierError("Not a resolvable python identifier selected.")
     return eval_node2(holding_scope, node)
 
 
 class ScopeNameFinder(object):
-
     def __init__(self, pymodule):
         self.module_scope = pymodule.get_scope()
         self.lines = pymodule.lines
         self.worder = worder.Worder(pymodule.source_code, True)
 
     def _is_defined_in_class_body(self, holding_scope, offset, lineno):
-        if lineno == holding_scope.get_start() and \
-           holding_scope.parent is not None and \
-           holding_scope.parent.get_kind() == 'Class' and \
-           self.worder.is_a_class_or_function_name_in_header(offset):
+        if (
+            lineno == holding_scope.get_start()
+            and holding_scope.parent is not None
+            and holding_scope.parent.get_kind() == "Class"
+            and self.worder.is_a_class_or_function_name_in_header(offset)
+        ):
             return True
-        if lineno != holding_scope.get_start() and \
-           holding_scope.get_kind() == 'Class' and \
-           self.worder.is_name_assigned_in_class_body(offset):
+        if (
+            lineno != holding_scope.get_start()
+            and holding_scope.get_kind() == "Class"
+            and self.worder.is_name_assigned_in_class_body(offset)
+        ):
             return True
         return False
 
     def _is_function_name_in_function_header(self, scope, offset, lineno):
-        if scope.get_start() <= lineno <= scope.get_body_start() and \
-           scope.get_kind() == 'Function' and \
-           self.worder.is_a_class_or_function_name_in_header(offset):
+        if (
+            scope.get_start() <= lineno <= scope.get_body_start()
+            and scope.get_kind() == "Function"
+            and self.worder.is_a_class_or_function_name_in_header(offset)
+        ):
             return True
         return False
 
@@ -80,14 +84,13 @@ class ScopeNameFinder(object):
 
     def get_primary_and_pyname_at(self, offset):
         lineno = self.lines.get_line_number(offset)
-        holding_scope = self.module_scope.get_inner_scope_for_line(lineno)
+        holding_scope = self.module_scope.get_inner_scope_for_offset(offset)
         # function keyword parameter
         if self.worder.is_function_keyword_parameter(offset):
             keyword_name = self.worder.get_word_at(offset)
             pyobject = self.get_enclosing_function(offset)
             if isinstance(pyobject, pyobjects.PyFunction):
-                return (None,
-                        pyobject.get_parameters().get(keyword_name, None))
+                return (None, pyobject.get_parameters().get(keyword_name, None))
         # class body
         if self._is_defined_in_class_body(holding_scope, offset, lineno):
             class_scope = holding_scope
@@ -99,13 +102,13 @@ class ScopeNameFinder(object):
             except rope.base.exceptions.AttributeNotFoundError:
                 return (None, None)
         # function header
-        if self._is_function_name_in_function_header(holding_scope,
-                                                     offset, lineno):
+        if self._is_function_name_in_function_header(holding_scope, offset, lineno):
             name = self.worder.get_primary_at(offset).strip()
             return (None, holding_scope.parent[name])
         # module in a from statement or an imported name that is aliased
-        if (self.worder.is_from_statement_module(offset) or
-            self.worder.is_import_statement_aliased_module(offset)):
+        if self.worder.is_from_statement_module(
+            offset
+        ) or self.worder.is_import_statement_aliased_module(offset):
             module = self.worder.get_primary_at(offset)
             module_pyname = self._find_module(module)
             return (None, module_pyname)
@@ -125,23 +128,24 @@ class ScopeNameFinder(object):
             pyobject = function_pyname.get_object()
             if isinstance(pyobject, pyobjects.AbstractFunction):
                 return pyobject
-            elif isinstance(pyobject, pyobjects.AbstractClass) and \
-                    '__init__' in pyobject:
-                return pyobject['__init__'].get_object()
-            elif '__call__' in pyobject:
-                return pyobject['__call__'].get_object()
+            elif (
+                isinstance(pyobject, pyobjects.AbstractClass) and "__init__" in pyobject
+            ):
+                return pyobject["__init__"].get_object()
+            elif "__call__" in pyobject:
+                return pyobject["__call__"].get_object()
         return None
 
     def _find_module(self, module_name):
         dots = 0
-        while module_name[dots] == '.':
+        while module_name[dots] == ".":
             dots += 1
         return rope.base.pynames.ImportedModule(
-            self.module_scope.pyobject, module_name[dots:], dots)
+            self.module_scope.pyobject, module_name[dots:], dots
+        )
 
 
 class StatementEvaluator(object):
-
     def __init__(self, scope):
         self.scope = scope
         self.result = None
@@ -167,16 +171,15 @@ class StatementEvaluator(object):
             return
 
         def _get_returned(pyobject):
-            args = arguments.create_arguments(primary, pyobject,
-                                              node, self.scope)
+            args = arguments.create_arguments(primary, pyobject, node, self.scope)
             return pyobject.get_returned_object(args)
+
         if isinstance(pyobject, rope.base.pyobjects.AbstractClass):
             result = None
-            if '__new__' in pyobject:
-                new_function = pyobject['__new__'].get_object()
+            if "__new__" in pyobject:
+                new_function = pyobject["__new__"].get_object()
                 result = _get_returned(new_function)
-            if result is None or \
-               result == rope.base.pyobjects.get_unknown():
+            if result is None or result == rope.base.pyobjects.get_unknown():
                 result = rope.base.pyobjects.PyObject(pyobject)
             self.result = rope.base.pynames.UnboundName(pyobject=result)
             return
@@ -184,15 +187,17 @@ class StatementEvaluator(object):
         pyfunction = None
         if isinstance(pyobject, rope.base.pyobjects.AbstractFunction):
             pyfunction = pyobject
-        elif '__call__' in pyobject:
-            pyfunction = pyobject['__call__'].get_object()
+        elif "__call__" in pyobject:
+            pyfunction = pyobject["__call__"].get_object()
         if pyfunction is not None:
             self.result = rope.base.pynames.UnboundName(
-                pyobject=_get_returned(pyfunction))
+                pyobject=_get_returned(pyfunction)
+            )
 
     def _Str(self, node):
         self.result = rope.base.pynames.UnboundName(
-            pyobject=rope.base.builtins.get_str())
+            pyobject=rope.base.builtins.get_str()
+        )
 
     def _Num(self, node):
         type_name = type(node.n).__name__
@@ -208,12 +213,12 @@ class StatementEvaluator(object):
 
     def _get_builtin_name(self, type_name):
         pytype = rope.base.builtins.builtins[type_name].get_object()
-        return rope.base.pynames.UnboundName(
-            rope.base.pyobjects.PyObject(pytype))
+        return rope.base.pynames.UnboundName(rope.base.pyobjects.PyObject(pytype))
 
     def _BinOp(self, node):
         self.result = rope.base.pynames.UnboundName(
-            self._get_object_for_node(node.left))
+            self._get_object_for_node(node.left)
+        )
 
     def _BoolOp(self, node):
         pyobject = self._get_object_for_node(node.values[0])
@@ -222,43 +227,50 @@ class StatementEvaluator(object):
         self.result = rope.base.pynames.UnboundName(pyobject)
 
     def _Repr(self, node):
-        self.result = self._get_builtin_name('str')
+        self.result = self._get_builtin_name("str")
 
     def _UnaryOp(self, node):
         self.result = rope.base.pynames.UnboundName(
-            self._get_object_for_node(node.operand))
+            self._get_object_for_node(node.operand)
+        )
 
     def _Compare(self, node):
-        self.result = self._get_builtin_name('bool')
+        self.result = self._get_builtin_name("bool")
 
     def _Dict(self, node):
         keys = None
         values = None
         if node.keys and node.keys[0]:
-            keys, values = next(iter(filter(itemgetter(0), zip(node.keys, node.values))), (None, None))
+            keys, values = next(
+                iter(filter(itemgetter(0), zip(node.keys, node.values))), (None, None)
+            )
             if keys:
                 keys = self._get_object_for_node(keys)
             if values:
                 values = self._get_object_for_node(values)
         self.result = rope.base.pynames.UnboundName(
-            pyobject=rope.base.builtins.get_dict(keys, values))
+            pyobject=rope.base.builtins.get_dict(keys, values)
+        )
 
     def _List(self, node):
         holding = None
         if node.elts:
             holding = self._get_object_for_node(node.elts[0])
         self.result = rope.base.pynames.UnboundName(
-            pyobject=rope.base.builtins.get_list(holding))
+            pyobject=rope.base.builtins.get_list(holding)
+        )
 
     def _ListComp(self, node):
         pyobject = self._what_does_comprehension_hold(node)
         self.result = rope.base.pynames.UnboundName(
-            pyobject=rope.base.builtins.get_list(pyobject))
+            pyobject=rope.base.builtins.get_list(pyobject)
+        )
 
     def _GeneratorExp(self, node):
         pyobject = self._what_does_comprehension_hold(node)
         self.result = rope.base.pynames.UnboundName(
-            pyobject=rope.base.builtins.get_iterator(pyobject))
+            pyobject=rope.base.builtins.get_iterator(pyobject)
+        )
 
     def _what_does_comprehension_hold(self, node):
         scope = self._make_comprehension_scope(node)
@@ -270,8 +282,9 @@ class StatementEvaluator(object):
         module = scope.pyobject.get_module()
         names = {}
         for comp in node.generators:
-            new_names = _get_evaluated_names(comp.target, comp.iter, module,
-                                             '.__iter__().next()', node.lineno)
+            new_names = _get_evaluated_names(
+                comp.target, comp.iter, module, ".__iter__().next()", node.lineno
+            )
             names.update(new_names)
         return rope.base.pyscopes.TemporaryScope(scope.pycore, scope, names)
 
@@ -284,7 +297,8 @@ class StatementEvaluator(object):
         else:
             objects.append(self._get_object_for_node(node.elts[0]))
         self.result = rope.base.pynames.UnboundName(
-            pyobject=rope.base.builtins.get_tuple(*objects))
+            pyobject=rope.base.builtins.get_tuple(*objects)
+        )
 
     def _get_object_for_node(self, stmt):
         pyname = eval_node(self.scope, stmt)
@@ -302,17 +316,14 @@ class StatementEvaluator(object):
 
     def _Subscript(self, node):
         if isinstance(node.slice, ast.Index):
-            self._call_function(node.value, '__getitem__',
-                                [node.slice.value])
+            self._call_function(node.value, "__getitem__", [node.slice.value])
         elif isinstance(node.slice, ast.Slice):
-            self._call_function(node.value, '__getitem__',
-                                [node.slice])
+            self._call_function(node.value, "__getitem__", [node.slice])
         elif isinstance(node.slice, ast.expr):
-            self._call_function(node.value, '__getitem__',
-                                [node.value])
+            self._call_function(node.value, "__getitem__", [node.value])
 
     def _Slice(self, node):
-        self.result = self._get_builtin_name('slice')
+        self.result = self._get_builtin_name("slice")
 
     def _call_function(self, node, function_name, other_args=None):
         pyname = eval_node(self.scope, node)
@@ -322,26 +333,26 @@ class StatementEvaluator(object):
             return
         if function_name in pyobject:
             called = pyobject[function_name].get_object()
-            if not called or \
-                    not isinstance(called, pyobjects.AbstractFunction):
+            if not called or not isinstance(called, pyobjects.AbstractFunction):
                 return
             args = [node]
             if other_args:
                 args += other_args
             arguments_ = arguments.Arguments(args, self.scope)
             self.result = rope.base.pynames.UnboundName(
-                pyobject=called.get_returned_object(arguments_))
+                pyobject=called.get_returned_object(arguments_)
+            )
 
     def _Lambda(self, node):
         self.result = rope.base.pynames.UnboundName(
-            pyobject=rope.base.builtins.Lambda(node, self.scope))
+            pyobject=rope.base.builtins.Lambda(node, self.scope)
+        )
 
 
 def _get_evaluated_names(targets, assigned, module, evaluation, lineno):
     result = {}
     for name, levels in astutils.get_name_levels(targets):
-        assignment = rope.base.pynames.AssignmentValue(assigned, levels,
-                                                       evaluation)
+        assignment = rope.base.pynames.AssignmentValue(assigned, levels, evaluation)
         # XXX: this module should not access `rope.base.pynamesdef`!
         pyname = rope.base.pynamesdef.AssignedName(lineno, module)
         pyname.assignments.append(assignment)
