@@ -7,7 +7,6 @@ from rope.refactor.importutils import importinfo
 
 
 class ModuleImports(object):
-
     def __init__(self, project, pymodule, import_filter=None):
         self.project = project
         self.pymodule = pymodule
@@ -35,7 +34,7 @@ class ModuleImports(object):
     def _get_all_star_list(self, pymodule):
         result = set()
         try:
-            all_star_list = pymodule.get_attribute('__all__')
+            all_star_list = pymodule.get_attribute("__all__")
         except exceptions.AttributeNotFoundError:
             return result
 
@@ -61,18 +60,22 @@ class ModuleImports(object):
         return result
 
     def remove_unused_imports(self):
-        can_select = _OneTimeSelector(self._get_unbound_names(self.pymodule) | self._get_all_star_list(self.pymodule))
+        can_select = _OneTimeSelector(
+            self._get_unbound_names(self.pymodule)
+            | self._get_all_star_list(self.pymodule)
+        )
         visitor = actions.RemovingVisitor(
-            self.project, self._current_folder(), can_select)
+            self.project, self._current_folder(), can_select
+        )
         for import_statement in self.imports:
             import_statement.accept(visitor)
 
     def get_used_imports(self, defined_pyobject):
         result = []
-        can_select = _OneTimeSelector(
-            self._get_unbound_names(defined_pyobject))
+        can_select = _OneTimeSelector(self._get_unbound_names(defined_pyobject))
         visitor = actions.FilteringVisitor(
-            self.project, self._current_folder(), can_select)
+            self.project, self._current_folder(), can_select
+        )
         for import_statement in self.imports:
             new_import = import_statement.accept(visitor)
             if new_import is not None and not new_import.is_empty():
@@ -80,9 +83,8 @@ class ModuleImports(object):
         return result
 
     def get_changed_source(self):
-        if (not self.project.prefs.get("pull_imports_to_top") and
-            not self.sorted):
-            return ''.join(self._rewrite_imports(self.imports))
+        if not self.project.prefs.get("pull_imports_to_top") and not self.sorted:
+            return "".join(self._rewrite_imports(self.imports))
 
         # Make sure we forward a removed import's preceding blank
         # lines count to the following import statement.
@@ -92,8 +94,7 @@ class ModuleImports(object):
                 stmt.blank_lines = max(prev_stmt.blank_lines, stmt.blank_lines)
             prev_stmt = stmt
         # The new list of imports.
-        imports = [stmt for stmt in self.imports
-                   if not stmt.import_info.is_empty()]
+        imports = [stmt for stmt in self.imports if not stmt.import_info.is_empty()]
 
         after_removing = self._remove_imports(self.imports)
         first_non_blank = self._first_non_blank_line(after_removing, 0)
@@ -105,16 +106,15 @@ class ModuleImports(object):
         sorted_imports = sorted(imports, key=self._get_location)
         for stmt in sorted_imports:
             if stmt != sorted_imports[0]:
-                result.append('\n' * stmt.blank_lines)
-            result.append(stmt.get_import_statement() + '\n')
+                result.append("\n" * stmt.blank_lines)
+            result.append(stmt.get_import_statement() + "\n")
         if sorted_imports and first_non_blank < len(after_removing):
-            result.append('\n' * self.separating_lines)
+            result.append("\n" * self.separating_lines)
 
         # Writing the body
-        first_after_imports = self._first_non_blank_line(after_removing,
-                                                         first_import)
+        first_after_imports = self._first_non_blank_line(after_removing, first_import)
         result.extend(after_removing[first_after_imports:])
-        return ''.join(result)
+        return "".join(result)
 
     def _get_import_location(self, stmt):
         start = stmt.get_new_start()
@@ -137,9 +137,10 @@ class ModuleImports(object):
             start, end = stmt.get_old_location()
             blank_lines = 0
             if start != first_import_line:
-                blank_lines = _count_blank_lines(lines.__getitem__, start - 2,
-                                                 last_index - 1, -1)
-            after_removing.extend(lines[last_index:start - 1 - blank_lines])
+                blank_lines = _count_blank_lines(
+                    lines.__getitem__, start - 2, last_index - 1, -1
+                )
+            after_removing.extend(lines[last_index : start - 1 - blank_lines])
             last_index = end - 1
         after_removing.extend(lines[last_index:])
         return after_removing
@@ -150,16 +151,15 @@ class ModuleImports(object):
         last_index = 0
         for stmt in imports:
             start, end = stmt.get_old_location()
-            after_rewriting.extend(lines[last_index:start - 1])
+            after_rewriting.extend(lines[last_index : start - 1])
             if not stmt.import_info.is_empty():
-                after_rewriting.append(stmt.get_import_statement() + '\n')
+                after_rewriting.append(stmt.get_import_statement() + "\n")
             last_index = end - 1
         after_rewriting.extend(lines[last_index:])
         return after_rewriting
 
     def _first_non_blank_line(self, lines, lineno):
-        return lineno + _count_blank_lines(lines.__getitem__, lineno,
-                                           len(lines))
+        return lineno + _count_blank_lines(lines.__getitem__, lineno, len(lines))
 
     def add_import(self, import_info):
         visitor = actions.AddingVisitor(self.project, [import_info])
@@ -169,9 +169,11 @@ class ModuleImports(object):
         else:
             lineno = self._get_new_import_lineno()
             blanks = self._get_new_import_blanks()
-            self.imports.append(importinfo.ImportStatement(
-                                import_info, lineno, lineno,
-                                blank_lines=blanks))
+            self.imports.append(
+                importinfo.ImportStatement(
+                    import_info, lineno, lineno, blank_lines=blanks
+                )
+            )
 
     def _get_new_import_blanks(self):
         return 0
@@ -183,22 +185,23 @@ class ModuleImports(object):
 
     def filter_names(self, can_select):
         visitor = actions.RemovingVisitor(
-            self.project, self._current_folder(), can_select)
+            self.project, self._current_folder(), can_select
+        )
         for import_statement in self.imports:
             import_statement.accept(visitor)
 
     def expand_stars(self):
         can_select = _OneTimeSelector(self._get_unbound_names(self.pymodule))
         visitor = actions.ExpandStarsVisitor(
-            self.project, self._current_folder(), can_select)
+            self.project, self._current_folder(), can_select
+        )
         for import_statement in self.imports:
             import_statement.accept(visitor)
 
     def remove_duplicates(self):
         added_imports = []
         for import_stmt in self.imports:
-            visitor = actions.AddingVisitor(self.project,
-                                            [import_stmt.import_info])
+            visitor = actions.AddingVisitor(self.project, [import_stmt.import_info])
             for added_import in added_imports:
                 if added_import.accept(visitor):
                     import_stmt.empty_import()
@@ -215,8 +218,8 @@ class ModuleImports(object):
                 for name_and_alias in import_info.names_and_aliases:
                     if hasattr(import_info, "module_name"):
                         new_import = importinfo.FromImport(
-                            import_info.module_name, import_info.level,
-                            [name_and_alias])
+                            import_info.module_name, import_info.level, [name_and_alias]
+                        )
                     else:
                         new_import = importinfo.NormalImport([name_and_alias])
                     self.add_import(new_import)
@@ -224,7 +227,8 @@ class ModuleImports(object):
 
     def get_relative_to_absolute_list(self):
         visitor = actions.RelativeToAbsoluteVisitor(
-            self.project, self._current_folder())
+            self.project, self._current_folder()
+        )
         for import_stmt in self.imports:
             if not import_stmt.readonly:
                 import_stmt.accept(visitor)
@@ -232,7 +236,8 @@ class ModuleImports(object):
 
     def get_self_import_fix_and_rename_list(self):
         visitor = actions.SelfImportVisitor(
-            self.project, self._current_folder(), self.pymodule.get_resource())
+            self.project, self._current_folder(), self.pymodule.get_resource()
+        )
         for import_stmt in self.imports:
             if not import_stmt.readonly:
                 import_stmt.accept(visitor)
@@ -269,22 +274,27 @@ class ModuleImports(object):
         if self.pymodule.get_doc() is not None:
             lineno = 1
         if len(nodes) > lineno:
-            if (isinstance(nodes[lineno], ast.Import) or
-                isinstance(nodes[lineno], ast.ImportFrom)):
+            if isinstance(nodes[lineno], ast.Import) or isinstance(
+                nodes[lineno], ast.ImportFrom
+            ):
                 return nodes[lineno].lineno
-            lineno = self.pymodule.logical_lines.logical_line_in(
-                nodes[lineno].lineno)[0]
+            lineno = self.pymodule.logical_lines.logical_line_in(nodes[lineno].lineno)[
+                0
+            ]
         else:
             lineno = self.pymodule.lines.length()
 
-        return lineno - _count_blank_lines(self.pymodule.lines.get_line,
-                                           lineno - 1, 1, -1)
+        return lineno - _count_blank_lines(
+            self.pymodule.lines.get_line, lineno - 1, 1, -1
+        )
 
     def _get_import_name(self, import_stmt):
         import_info = import_stmt.import_info
         if hasattr(import_info, "module_name"):
-            return "%s.%s" % (import_info.module_name,
-                              import_info.names_and_aliases[0][0])
+            return "%s.%s" % (
+                import_info.module_name,
+                import_info.names_and_aliases[0][0],
+            )
         else:
             return import_info.names_and_aliases[0][0]
 
@@ -292,13 +302,13 @@ class ModuleImports(object):
         str1 = stm1.get_import_statement()
         return str1.startswith("from "), str1
 
-        #str1 = stmt1.get_import_statement()
-        #str2 = stmt2.get_import_statement()
-        #if str1.startswith('from ') and not str2.startswith('from '):
+        # str1 = stmt1.get_import_statement()
+        # str2 = stmt2.get_import_statement()
+        # if str1.startswith('from ') and not str2.startswith('from '):
         #    return 1
-        #if not str1.startswith('from ') and str2.startswith('from '):
+        # if not str1.startswith('from ') and str2.startswith('from '):
         #    return -1
-        #return cmp(str1, str2)
+        # return cmp(str1, str2)
 
     def _move_imports(self, imports, index, blank_lines):
         if imports:
@@ -312,7 +322,8 @@ class ModuleImports(object):
 
     def handle_long_imports(self, maxdots, maxlength):
         visitor = actions.LongImportVisitor(
-            self._current_folder(), self.project, maxdots, maxlength)
+            self._current_folder(), self.project, maxdots, maxlength
+        )
         for import_statement in self.imports:
             if not import_statement.readonly:
                 import_statement.accept(visitor)
@@ -322,8 +333,9 @@ class ModuleImports(object):
 
     def remove_pyname(self, pyname):
         """Removes pyname when imported in ``from mod import x``"""
-        visitor = actions.RemovePyNameVisitor(self.project, self.pymodule,
-                                              pyname, self._current_folder())
+        visitor = actions.RemovePyNameVisitor(
+            self.project, self.pymodule, pyname, self._current_folder()
+        )
         for import_stmt in self.imports:
             import_stmt.accept(visitor)
 
@@ -331,7 +343,7 @@ class ModuleImports(object):
 def _count_blank_lines(get_line, start, end, step=1):
     count = 0
     for idx in range(start, end, step):
-        if get_line(idx).strip() == '':
+        if get_line(idx).strip() == "":
             count += 1
         else:
             break
@@ -339,7 +351,6 @@ def _count_blank_lines(get_line, start, end, step=1):
 
 
 class _OneTimeSelector(object):
-
     def __init__(self, names):
         self.names = names
         self.selected_names = set()
@@ -352,9 +363,9 @@ class _OneTimeSelector(object):
         return False
 
     def _get_dotted_tokens(self, imported_primary):
-        tokens = imported_primary.split('.')
+        tokens = imported_primary.split(".")
         for i in range(len(tokens)):
-            yield '.'.join(tokens[:i + 1])
+            yield ".".join(tokens[: i + 1])
 
     def _can_name_be_added(self, imported_primary):
         for name in self._get_dotted_tokens(imported_primary):
@@ -364,13 +375,16 @@ class _OneTimeSelector(object):
 
 
 class _UnboundNameFinder(object):
-
     def __init__(self, pyobject):
         self.pyobject = pyobject
 
     def _visit_child_scope(self, node):
-        pyobject = self.pyobject.get_module().get_scope().\
-            get_inner_scope_for_line(node.lineno).pyobject
+        pyobject = (
+            self.pyobject.get_module()
+            .get_scope()
+            .get_inner_scope_for_line(node.lineno)
+            .pyobject
+        )
         visitor = _LocalUnboundNameFinder(pyobject, self)
         for child in ast.get_child_nodes(node):
             ast.walk(child, visitor)
@@ -382,8 +396,7 @@ class _UnboundNameFinder(object):
         self._visit_child_scope(node)
 
     def _Name(self, node):
-        if self._get_root()._is_node_interesting(node) and \
-           not self.is_bound(node.id):
+        if self._get_root()._is_node_interesting(node) and not self.is_bound(node.id):
             self.add_unbound(node.id)
 
     def _Attribute(self, node):
@@ -393,9 +406,10 @@ class _UnboundNameFinder(object):
             node = node.value
         if isinstance(node, ast.Name):
             result.append(node.id)
-            primary = '.'.join(reversed(result))
-            if self._get_root()._is_node_interesting(node) and \
-               not self.is_bound(primary):
+            primary = ".".join(reversed(result))
+            if self._get_root()._is_node_interesting(node) and not self.is_bound(
+                primary
+            ):
                 self.add_unbound(primary)
         else:
             ast.walk(node, self)
@@ -411,14 +425,12 @@ class _UnboundNameFinder(object):
 
 
 class _GlobalUnboundNameFinder(_UnboundNameFinder):
-
     def __init__(self, pymodule, wanted_pyobject):
         super(_GlobalUnboundNameFinder, self).__init__(pymodule)
         self.unbound = set()
         self.names = set()
         for name, pyname in pymodule._get_structural_attributes().items():
-            if not isinstance(pyname, (pynames.ImportedName,
-                                       pynames.ImportedModule)):
+            if not isinstance(pyname, (pynames.ImportedName, pynames.ImportedModule)):
                 self.names.add(name)
         wanted_scope = wanted_pyobject.get_scope()
         self.start = wanted_scope.get_start()
@@ -428,20 +440,19 @@ class _GlobalUnboundNameFinder(_UnboundNameFinder):
         return self
 
     def is_bound(self, primary, propagated=False):
-        name = primary.split('.')[0]
+        name = primary.split(".")[0]
         return name in self.names
 
     def add_unbound(self, name):
-        names = name.split('.')
+        names = name.split(".")
         for i in range(len(names)):
-            self.unbound.add('.'.join(names[:i + 1]))
+            self.unbound.add(".".join(names[: i + 1]))
 
     def _is_node_interesting(self, node):
         return self.start <= node.lineno < self.end
 
 
 class _LocalUnboundNameFinder(_UnboundNameFinder):
-
     def __init__(self, pyobject, parent):
         super(_LocalUnboundNameFinder, self).__init__(pyobject)
         self.parent = parent
@@ -450,7 +461,7 @@ class _LocalUnboundNameFinder(_UnboundNameFinder):
         return self.parent._get_root()
 
     def is_bound(self, primary, propagated=False):
-        name = primary.split('.')[0]
+        name = primary.split(".")[0]
         if propagated:
             names = self.pyobject.get_scope().get_propagated_names()
         else:
@@ -464,7 +475,6 @@ class _LocalUnboundNameFinder(_UnboundNameFinder):
 
 
 class _GlobalImportFinder(object):
-
     def __init__(self, pymodule):
         self.current_folder = None
         if pymodule.get_resource():
@@ -478,16 +488,18 @@ class _GlobalImportFinder(object):
         start_line = node.lineno
         import_statement = importinfo.ImportStatement(
             importinfo.NormalImport(self._get_names(node.names)),
-            start_line, end_line, self._get_text(start_line, end_line),
-            blank_lines=self._count_empty_lines_before(start_line))
+            start_line,
+            end_line,
+            self._get_text(start_line, end_line),
+            blank_lines=self._count_empty_lines_before(start_line),
+        )
         self.imports.append(import_statement)
 
     def _count_empty_lines_before(self, lineno):
         return _count_blank_lines(self.lines.get_line, lineno - 1, 0, -1)
 
     def _count_empty_lines_after(self, lineno):
-        return _count_blank_lines(self.lines.get_line, lineno + 1,
-                                  self.lines.length())
+        return _count_blank_lines(self.lines.get_line, lineno + 1, self.lines.length())
 
     def get_separating_line_count(self):
         if not self.imports:
@@ -498,21 +510,27 @@ class _GlobalImportFinder(object):
         result = []
         for index in range(start_line, end_line):
             result.append(self.lines.get_line(index))
-        return '\n'.join(result)
+        return "\n".join(result)
 
     def visit_from(self, node, end_line):
         level = 0
         if node.level:
             level = node.level
         import_info = importinfo.FromImport(
-            node.module or '',  # see comment at rope.base.ast.walk
-            level, self._get_names(node.names))
+            node.module or "",  # see comment at rope.base.ast.walk
+            level,
+            self._get_names(node.names),
+        )
         start_line = node.lineno
-        self.imports.append(importinfo.ImportStatement(
-                            import_info, node.lineno, end_line,
-                            self._get_text(start_line, end_line),
-                            blank_lines=
-                            self._count_empty_lines_before(start_line)))
+        self.imports.append(
+            importinfo.ImportStatement(
+                import_info,
+                node.lineno,
+                end_line,
+                self._get_text(start_line, end_line),
+                blank_lines=self._count_empty_lines_before(start_line),
+            )
+        )
 
     def _get_names(self, alias_names):
         result = []
